#!/usr/bin/env python
# coding: utf-8

debug = True
debug = False

root = '/home/user/dev/tao1'

database={"login":"admin", "pass":"Gthcgtrnbdf", "host":["127.0.0.1:27017"], "port":"", 'name':'daoerp'}
# database={"login":"test", "pass":"passwd", "host":["127.0.0.1:27017"], 'name':'test'}